"""
Altan SDK - Integration Module

Access to 5000+ platform integrations for social media, CRM, and other services.
"""

from .integration import Integration
from .connection import Connection

__all__ = ["Integration", "Connection"]
